Chapter: Optional
=================

This chapter contains optional tutorials expanding on different aspects of how **PyAutoGalaxy** work.

The chapter contains the following tutorials:

`Tutorial: Mass Profiles  <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_optional/tutorial_mass_profiles.ipynb>`_
- A description of mass profiles implemented in PyAutoGalaxy, which are currently only used by its child project PyAutoLens.

`Tutorial: Sub-grids  <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_optional/tutorial_sub_grids.ipynb>`_
- Use sub-grids to perform more accurate and precise calculations.

`Tutorial: Searches  <https://mybinder.org/v2/gh/Jammy2211/autogalaxy_workspace/release?filepath=notebooks/howtogalaxy/chapter_optional/tutorial_searches.ipynb>`_
- Alternative non-linear searches to sample parameter space.

